@@ -6,9 +6,11 @@ import git
 import json
 import logging
 import os
+import re
 import requests
 import requests_cache
 import shutil
+import time
 
 import nf_core
 import nf_core.create
@@ -320,27 +322,39 @@ class PipelineSync(object):
             "base": self.from_branch,
         }
 
-        r = requests.post(
-            url="https://api.github.com/repos/{}/pulls".format(self.gh_repo),
-            data=json.dumps(pr_content),
-            auth=requests.auth.HTTPBasicAuth(self.gh_username, os.environ["GITHUB_AUTH_TOKEN"]),
-        )
-        try:
-            self.gh_pr_returned_data = json.loads(r.content)
-            returned_data_prettyprint = json.dumps(self.gh_pr_returned_data, indent=4)
-        except:
-            self.gh_pr_returned_data = r.content
-            returned_data_prettyprint = r.content
+        while True:
+            r = requests.post(
+                url="https://api.github.com/repos/{}/pulls".format(self.gh_repo),
+                data=json.dumps(pr_content),
+                auth=requests.auth.HTTPBasicAuth(self.gh_username, os.environ["GITHUB_AUTH_TOKEN"]),
+            )
+            try:
+                self.gh_pr_returned_data = json.loads(r.content)
+                returned_data_prettyprint = json.dumps(self.gh_pr_returned_data, indent=4)
+            except:
+                self.gh_pr_returned_data = r.content
+                returned_data_prettyprint = r.content
 
-        # PR worked
-        if r.status_code == 201:
-            self.pr_url = self.gh_pr_returned_data["html_url"]
-            log.debug("GitHub API PR worked:\n{}".format(returned_data_prettyprint))
-            log.info("GitHub PR created: {}".format(self.gh_pr_returned_data["html_url"]))
+            # PR worked
+            if r.status_code == 201:
+                self.pr_url = self.gh_pr_returned_data["html_url"]
+                log.debug(f"GitHub API PR worked:\n{returned_data_prettyprint}")
+                log.info(f"GitHub PR created: {self.gh_pr_returned_data['html_url']}")
+                break
 
-        # Something went wrong
-        else:
-            raise PullRequestException(f"GitHub API returned code {r.status_code}: \n{returned_data_prettyprint}")
+            # Returned 403 error - too many simultaneous requests
+            # https://github.com/nf-core/tools/issues/911
+            if r.status_code == 403:
+                log.debug(f"GitHub API PR failed with 403 error:\n{returned_data_prettyprint}\n\n{r.headers}")
+                wait_time = float(re.sub("[^0-9]", "", r.headers.get("Retry-After", 30)))
+                log.warning(f"Got 403 code - probably the abuse protection. Trying again after {wait_time} seconds..")
+                time.sleep(wait_time)
+
+            # Something went wrong
+            else:
+                raise PullRequestException(
+                    f"GitHub API returned code {r.status_code}: \n\n{returned_data_prettyprint}\n\n{r.headers}"
+                )
 
     def close_open_template_merge_prs(self):
         """Get all template merging branches (starting with 'nf-core-template-merge-')
